Struct ZcosmicWorkspaceHandleV2

pub struct ZcosmicWorkspaceHandleV2 { /* private fields */ }
Available on crate feature wayland and Linux only.
a workspace handing a group of surfaces

A zcosmic_workspace_handle_v2 object represents a a workspace that handles a group of surfaces.

Each workspace has a name, conveyed to the client with the name event; a list of states, conveyed to the client with the state event; and optionally a set of coordinates, conveyed to the client with the coordinates event. The client may request that the compositor activate or deactivate the workspace.

Each workspace can belong to only a single workspace group. Depepending on the compositor policy, there might be workspaces with the same name in different workspace groups, but these workspaces are still separate (e.g. one of them might be active while the other is not).

See also the Event enum for this interface.

Implementations

Source

impl ZcosmicWorkspaceHandleV2

pub fn destroy(&self)

destroy the zcosmic_workspace_handle_v1 object

This request should be called either when the client will no longer use the zcosmic_workspace_handle_v1.

pub fn rename(&self, name: String)

rename this workspace

Request that this workspace is renamed.

There is no guarantee the workspace will actually be renamed.

pub fn set_tiling_state(&self, state: TilingState)

change the tiling state of this workspace

Request that this workspace’s tiling state is changed.

There is no guarantee the workspace will actually change it’s tiling state.

pub fn move_before(&self, other_workspace: &ExtWorkspaceHandleV1, axis: u32)

move before a different workspace

Move a workspace to be before another workspace along a given axis.

other_workspace may be on the same workspace group, or on a different group. If it’s a different set, the workspace will also be moved to that group.

axis should be a valid index in the coordinates on the workspace group other_workspace is on. The workspace will be positioned on the target group to have a coordinate with this component less than the value of the component for other_workspace. The exact coordinate values, or how other workspaces are moved to accommodate the workspace, is unspecified.

The request will be ignored if axis is invalid or the compositor is otherwise unable to move the workspace.

There is no guarantee the workspace will actually be moved.

pub fn move_after(&self, other_workspace: &ExtWorkspaceHandleV1, axis: u32)

move after a different workspace

Move a workspace to be after another workspace along a given axis.

See move_before.

pub fn pin(&self)

pin the workspace

Request that this workspace be pinned.

There is no guarantee the workspace will be actually pinned.

pub fn unpin(&self)

pin the workspace

Request that this workspace be unpinned.

There is no guarantee the workspace will be actually unpinned.